package com.ips.system.controller;

import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ips.common.annotation.Log;
import com.ips.common.core.controller.BaseController;
import com.ips.common.core.domain.AjaxResult;
import com.ips.common.enums.BusinessType;
import com.ips.system.domain.AlgorithmConfig;
import com.ips.system.service.IAlgorithmConfigService;
import com.ips.common.utils.poi.ExcelUtil;
import com.ips.common.core.page.TableDataInfo;

/**
 * 算法配置Controller
 * 
 * @author Allen
 * @date 2025-05-21
 */
@RestController
@RequestMapping("/biz/config")
public class AlgorithmConfigController extends BaseController
{
    @Autowired
    private IAlgorithmConfigService algorithmConfigService;

    /**
     * 查询算法配置列表
     */
    @PreAuthorize("@ss.hasPermi('biz:config:list')")
    @GetMapping("/list")
    public TableDataInfo list(AlgorithmConfig algorithmConfig)
    {
        startPage();
        List<AlgorithmConfig> list = algorithmConfigService.selectAlgorithmConfigList(algorithmConfig);
        return getDataTable(list);
    }

    /**
     * 导出算法配置列表
     */
    @PreAuthorize("@ss.hasPermi('biz:config:export')")
    @Log(title = "算法配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AlgorithmConfig algorithmConfig)
    {
        List<AlgorithmConfig> list = algorithmConfigService.selectAlgorithmConfigList(algorithmConfig);
        ExcelUtil<AlgorithmConfig> util = new ExcelUtil<AlgorithmConfig>(AlgorithmConfig.class);
        util.exportExcel(response, list, "算法配置数据");
    }

    /**
     * 获取算法配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('biz:config:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(algorithmConfigService.selectAlgorithmConfigById(id));
    }

    /**
     * 新增算法配置
     */
    @PreAuthorize("@ss.hasPermi('biz:config:add')")
    @Log(title = "算法配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AlgorithmConfig algorithmConfig)
    {
        return toAjax(algorithmConfigService.insertAlgorithmConfig(algorithmConfig));
    }

    /**
     * 修改算法配置
     */
    @PreAuthorize("@ss.hasPermi('biz:config:edit')")
    @Log(title = "算法配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AlgorithmConfig algorithmConfig)
    {
        return toAjax(algorithmConfigService.updateAlgorithmConfig(algorithmConfig));
    }

    /**
     * 删除算法配置
     */
    @PreAuthorize("@ss.hasPermi('biz:config:remove')")
    @Log(title = "算法配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(algorithmConfigService.deleteAlgorithmConfigByIds(ids));
    }

    /**
     * 根据类型获取算法配置
     * @param type
     * @return
     */
    @GetMapping("/getOptionsByType/{type}")
    public AjaxResult getOptionsByType(@PathVariable("type")String type)
    {
        return success(algorithmConfigService.getOptionsByType(type));
    }
}
