package com.ips.system.controller;

import org.springframework.core.io.FileSystemResource;
import org.springframework.core.io.Resource;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.io.File;

@RestController
@RequestMapping("/biz/common")
public class BizCommonController {

    /**
     * 获取静态资源
     * @param filePath
     * @return
     */
    @GetMapping("/getStatic")
    public ResponseEntity<Resource> getStaticFile(@RequestParam String filePath) {
        // 安全检查 - 防止路径遍历攻击
        if (!isSafePath(filePath)) {
            return ResponseEntity.badRequest().build();
        }

        File file = new File(filePath);
        if (!file.exists()) {
            return ResponseEntity.notFound().build();
        }

        Resource resource = new FileSystemResource(file);

        // 设置Content-Type
        String contentType = determineContentType(file.getName());

        return ResponseEntity.ok()
                .contentType(MediaType.parseMediaType(contentType))
                .header(HttpHeaders.CONTENT_DISPOSITION, "inline; filename=\"" + file.getName() + "\"")
                .body(resource);
    }

    private boolean isSafePath(String filePath) {
        // 这里添加你的安全检查逻辑
        // 例如：禁止相对路径、限制特定目录等
        return true; // 临时返回true，实际使用时需要实现
    }

    private String determineContentType(String filename) {
        // 简单的内容类型判断
        if (filename.endsWith(".jpg") || filename.endsWith(".jpeg")) {
            return "image/jpeg";
        } else if (filename.endsWith(".png")) {
            return "image/png";
        } else if (filename.endsWith(".gif")) {
            return "image/gif";
        } else if (filename.endsWith(".pdf")) {
            return "application/pdf";
        } else if (filename.endsWith(".json")) {
            return "application/json";
        } else if (filename.endsWith(".csv")) {
            return "text/csv";
        } else if (filename.endsWith(".txt")) {
            return "text/plain";
        } else {
            return "application/octet-stream";
        }
    }
}

