package com.ips.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.ips.common.utils.StringUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ips.common.annotation.Log;
import com.ips.common.core.controller.BaseController;
import com.ips.common.core.domain.AjaxResult;
import com.ips.common.enums.BusinessType;
import com.ips.system.domain.BizTraining;
import com.ips.system.service.IBizTrainingService;
import com.ips.common.utils.poi.ExcelUtil;
import com.ips.common.core.page.TableDataInfo;

/**
 * 模型训练Controller
 * 
 * @author Allen
 * @date 2025-05-21
 */
@RestController
@RequestMapping("/biz/training")
public class BizTrainingController extends BaseController
{
    @Autowired
    private IBizTrainingService bizTrainingService;

    /**
     * 查询模型训练列表
     */
    @PreAuthorize("@ss.hasPermi('biz:training:list')")
    @GetMapping("/list")
    public TableDataInfo list(BizTraining bizTraining)
    {
        startPage();
        List<BizTraining> list = bizTrainingService.selectBizTrainingList(bizTraining);
        return getDataTable(list);
    }

    /**
     * 导出模型训练列表
     */
    @PreAuthorize("@ss.hasPermi('biz:training:export')")
    @Log(title = "模型训练", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BizTraining bizTraining)
    {
        List<BizTraining> list = bizTrainingService.selectBizTrainingList(bizTraining);
        ExcelUtil<BizTraining> util = new ExcelUtil<BizTraining>(BizTraining.class);
        util.exportExcel(response, list, "模型训练数据");
    }

    /**
     * 获取模型训练详细信息
     */
    @PreAuthorize("@ss.hasPermi('biz:training:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bizTrainingService.selectBizTrainingById(id));
    }

    /**
     * 新增模型训练
     */
    @PreAuthorize("@ss.hasPermi('biz:training:add')")
    @Log(title = "模型训练", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BizTraining bizTraining)
    {
        return toAjax(bizTrainingService.insertBizTraining(bizTraining));
    }

    /**
     * 修改模型训练
     */
    @PreAuthorize("@ss.hasPermi('biz:training:edit')")
    @Log(title = "模型训练", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BizTraining bizTraining)
    {
        return toAjax(bizTrainingService.updateBizTraining(bizTraining));
    }

    /**
     * 删除模型训练
     */
    @PreAuthorize("@ss.hasPermi('biz:training:remove')")
    @Log(title = "模型训练", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(bizTrainingService.deleteBizTrainingByIds(ids));
    }

    /**
     * 运行算法模型
     * @param id
     * @return
     * @throws JsonProcessingException
     */
    @PreAuthorize("@ss.hasPermi('biz:training:add')")
    @GetMapping(value = "/run/{id}")
    public AjaxResult run(@PathVariable("id") Long id) throws JsonProcessingException {
        String errorMsg = bizTrainingService.run(id);
        if(StringUtils.isEmpty(errorMsg)){
            return success(errorMsg);
        } else {
            return error(errorMsg);
        }
    }

    /**
     * 获取结果详情
     * @param id
     * @return
     * @throws JsonProcessingException
     */
    @PreAuthorize("@ss.hasPermi('biz:training:add')")
    @GetMapping(value = "/getResultDetails/{id}")
    public AjaxResult getResultDetails(@PathVariable("id") Long id) throws JsonProcessingException {
        BizTraining obj = bizTrainingService.getResultDetails(id);
        if(obj != null){
            return success(obj);
        } else {
            return error("获取详情失败");
        }
    }

    @PreAuthorize("@ss.hasPermi('biz:training:add')")
    @GetMapping(value = "/getTaskStatusIsChanged/{id}")
    public AjaxResult getTaskStatusIsChanged(@PathVariable("id") Long id){
        return success(bizTrainingService.getTaskStatusIsChanged(id));
    }
}
