package com.ips.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.ips.common.utils.StringUtils;
import com.ips.system.domain.Preprocessed;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ips.common.annotation.Log;
import com.ips.common.core.controller.BaseController;
import com.ips.common.core.domain.AjaxResult;
import com.ips.common.enums.BusinessType;
import com.ips.system.domain.ExtractedFeatures;
import com.ips.system.service.IExtractedFeaturesService;
import com.ips.common.utils.poi.ExcelUtil;
import com.ips.common.core.page.TableDataInfo;

/**
 * 特征提取Controller
 * 
 * @author Allen
 * @date 2025-05-21
 */
@RestController
@RequestMapping("/biz/features")
public class ExtractedFeaturesController extends BaseController
{
    @Autowired
    private IExtractedFeaturesService extractedFeaturesService;

    /**
     * 查询特征提取列表
     */
    @PreAuthorize("@ss.hasPermi('biz:features:list')")
    @GetMapping("/list")
    public TableDataInfo list(ExtractedFeatures extractedFeatures)
    {
        startPage();
        List<ExtractedFeatures> list = extractedFeaturesService.selectExtractedFeaturesList(extractedFeatures);
        return getDataTable(list);
    }

    /**
     * 导出特征提取列表
     */
    @PreAuthorize("@ss.hasPermi('biz:features:export')")
    @Log(title = "特征提取", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ExtractedFeatures extractedFeatures)
    {
        List<ExtractedFeatures> list = extractedFeaturesService.selectExtractedFeaturesList(extractedFeatures);
        ExcelUtil<ExtractedFeatures> util = new ExcelUtil<ExtractedFeatures>(ExtractedFeatures.class);
        util.exportExcel(response, list, "特征提取数据");
    }

    /**
     * 获取特征提取详细信息
     */
    @PreAuthorize("@ss.hasPermi('biz:features:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(extractedFeaturesService.selectExtractedFeaturesById(id));
    }

    /**
     * 新增特征提取
     */
    @PreAuthorize("@ss.hasPermi('biz:features:add')")
    @Log(title = "特征提取", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ExtractedFeatures extractedFeatures)
    {
        return toAjax(extractedFeaturesService.insertExtractedFeatures(extractedFeatures));
    }

    /**
     * 修改特征提取
     */
    @PreAuthorize("@ss.hasPermi('biz:features:edit')")
    @Log(title = "特征提取", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ExtractedFeatures extractedFeatures)
    {
        return toAjax(extractedFeaturesService.updateExtractedFeatures(extractedFeatures));
    }

    /**
     * 删除特征提取
     */
    @PreAuthorize("@ss.hasPermi('biz:features:remove')")
    @Log(title = "特征提取", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(extractedFeaturesService.deleteExtractedFeaturesByIds(ids));
    }

    /**
     * 运行算法模型
     * @param id
     * @return
     * @throws JsonProcessingException
     */
    @PreAuthorize("@ss.hasPermi('biz:features:add')")
    @GetMapping(value = "/run/{id}")
    public AjaxResult run(@PathVariable("id") Long id) throws JsonProcessingException {
        String errorMsg = extractedFeaturesService.run(id);
        if(StringUtils.isEmpty(errorMsg)){
            return success(errorMsg);
        } else {
            return error(errorMsg);
        }
    }

    /**
     * 获取结果详情
     * @param id
     * @return
     * @throws JsonProcessingException
     */
    @PreAuthorize("@ss.hasPermi('biz:features:add')")
    @GetMapping(value = "/getResultDetails/{id}")
    public AjaxResult getResultDetails(@PathVariable("id") Long id) throws JsonProcessingException {
        ExtractedFeatures obj = extractedFeaturesService.getResultDetails(id);
        if(obj != null){
            return success(obj);
        } else {
            return error("获取详情失败");
        }
    }

    @PreAuthorize("@ss.hasPermi('biz:features:add')")
    @GetMapping(value = "/getTaskStatusIsChanged/{id}")
    public AjaxResult getTaskStatusIsChanged(@PathVariable("id") Long id){
        return success(extractedFeaturesService.getTaskStatusIsChanged(id));
    }
}
