package com.ips.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.ips.common.utils.StringUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ips.common.annotation.Log;
import com.ips.common.core.controller.BaseController;
import com.ips.common.core.domain.AjaxResult;
import com.ips.common.enums.BusinessType;
import com.ips.system.domain.Preprocessed;
import com.ips.system.service.IPreprocessedService;
import com.ips.common.utils.poi.ExcelUtil;
import com.ips.common.core.page.TableDataInfo;

/**
 * 数据预处理Controller
 * 
 * @author Allen
 * @date 2025-05-21
 */
@RestController
@RequestMapping("/biz/preprocessed")
public class PreprocessedController extends BaseController
{
    @Autowired
    private IPreprocessedService preprocessedService;

    /**
     * 查询数据预处理列表
     */
    @PreAuthorize("@ss.hasPermi('biz:preprocessed:list')")
    @GetMapping("/list")
    public TableDataInfo list(Preprocessed preprocessed)
    {
        startPage();
        List<Preprocessed> list = preprocessedService.selectPreprocessedList(preprocessed);
        return getDataTable(list);
    }

    /**
     * 导出数据预处理列表
     */
    @PreAuthorize("@ss.hasPermi('biz:preprocessed:export')")
    @Log(title = "数据预处理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Preprocessed preprocessed)
    {
        List<Preprocessed> list = preprocessedService.selectPreprocessedList(preprocessed);
        ExcelUtil<Preprocessed> util = new ExcelUtil<Preprocessed>(Preprocessed.class);
        util.exportExcel(response, list, "数据预处理数据");
    }

    /**
     * 获取数据预处理详细信息
     */
    @PreAuthorize("@ss.hasPermi('biz:preprocessed:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(preprocessedService.selectPreprocessedById(id));
    }

    /**
     * 新增数据预处理
     */
    @PreAuthorize("@ss.hasPermi('biz:preprocessed:add')")
    @Log(title = "数据预处理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Preprocessed preprocessed)
    {
        return toAjax(preprocessedService.insertPreprocessed(preprocessed));
    }

    /**
     * 修改数据预处理
     */
    @PreAuthorize("@ss.hasPermi('biz:preprocessed:edit')")
    @Log(title = "数据预处理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Preprocessed preprocessed)
    {
        return toAjax(preprocessedService.updatePreprocessed(preprocessed));
    }

    /**
     * 删除数据预处理
     */
    @PreAuthorize("@ss.hasPermi('biz:preprocessed:remove')")
    @Log(title = "数据预处理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(preprocessedService.deletePreprocessedByIds(ids));
    }

    /**
     * 运行算法模型
     * @param id
     * @return
     * @throws JsonProcessingException
     */
    @PreAuthorize("@ss.hasPermi('biz:preprocessed:add')")
    @GetMapping(value = "/run/{id}")
    public AjaxResult run(@PathVariable("id") Long id) throws JsonProcessingException {
        String errorMsg = preprocessedService.run(id);
        if(StringUtils.isEmpty(errorMsg)){
            return success(errorMsg);
        } else {
            return error(errorMsg);
        }
    }

    /**
     * 获取结果详情
     * @param id
     * @return
     * @throws JsonProcessingException
     */
    @PreAuthorize("@ss.hasPermi('biz:preprocessed:add')")
    @GetMapping(value = "/getResultDetails/{id}")
    public AjaxResult getResultDetails(@PathVariable("id") Long id) throws JsonProcessingException {
        Preprocessed obj = preprocessedService.getResultDetails(id);
        if(obj != null){
            return success(obj);
        } else {
            return error("获取详情失败");
        }
    }

    @PreAuthorize("@ss.hasPermi('biz:preprocessed:add')")
    @GetMapping(value = "/getTaskStatusIsChanged/{id}")
    public AjaxResult getTaskStatusIsChanged(@PathVariable("id") Long id){
        return success(preprocessedService.getTaskStatusIsChanged(id));
    }
}
