package com.ips.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.ips.common.utils.StringUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ips.common.annotation.Log;
import com.ips.common.core.controller.BaseController;
import com.ips.common.core.domain.AjaxResult;
import com.ips.common.enums.BusinessType;
import com.ips.system.domain.TimeFrequencyImages;
import com.ips.system.service.ITimeFrequencyImagesService;
import com.ips.common.utils.poi.ExcelUtil;
import com.ips.common.core.page.TableDataInfo;

/**
 * 时频图生成Controller
 * 
 * @author Allen
 * @date 2025-05-28
 */
@RestController
@RequestMapping("/biz/images")
public class TimeFrequencyImagesController extends BaseController
{
    @Autowired
    private ITimeFrequencyImagesService timeFrequencyImagesService;

    /**
     * 查询时频图生成列表
     */
    @PreAuthorize("@ss.hasPermi('biz:images:list')")
    @GetMapping("/list")
    public TableDataInfo list(TimeFrequencyImages timeFrequencyImages)
    {
        startPage();
        List<TimeFrequencyImages> list = timeFrequencyImagesService.selectTimeFrequencyImagesList(timeFrequencyImages);
        return getDataTable(list);
    }

    /**
     * 导出时频图生成列表
     */
    @PreAuthorize("@ss.hasPermi('biz:images:export')")
    @Log(title = "时频图生成", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TimeFrequencyImages timeFrequencyImages)
    {
        List<TimeFrequencyImages> list = timeFrequencyImagesService.selectTimeFrequencyImagesList(timeFrequencyImages);
        ExcelUtil<TimeFrequencyImages> util = new ExcelUtil<TimeFrequencyImages>(TimeFrequencyImages.class);
        util.exportExcel(response, list, "时频图生成数据");
    }

    /**
     * 获取时频图生成详细信息
     */
    @PreAuthorize("@ss.hasPermi('biz:images:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(timeFrequencyImagesService.selectTimeFrequencyImagesById(id));
    }

    /**
     * 新增时频图生成
     */
    @PreAuthorize("@ss.hasPermi('biz:images:add')")
    @Log(title = "时频图生成", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TimeFrequencyImages timeFrequencyImages)
    {
        return toAjax(timeFrequencyImagesService.insertTimeFrequencyImages(timeFrequencyImages));
    }

    /**
     * 修改时频图生成
     */
    @PreAuthorize("@ss.hasPermi('biz:images:edit')")
    @Log(title = "时频图生成", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TimeFrequencyImages timeFrequencyImages)
    {
        return toAjax(timeFrequencyImagesService.updateTimeFrequencyImages(timeFrequencyImages));
    }

    /**
     * 删除时频图生成
     */
    @PreAuthorize("@ss.hasPermi('biz:images:remove')")
    @Log(title = "时频图生成", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(timeFrequencyImagesService.deleteTimeFrequencyImagesByIds(ids));
    }

    /**
     * 运行算法模型
     * @param id
     * @return
     * @throws JsonProcessingException
     */
    @PreAuthorize("@ss.hasPermi('biz:images:add')")
    @GetMapping(value = "/run/{id}")
    public AjaxResult run(@PathVariable("id") Long id) throws JsonProcessingException {
        String errorMsg = timeFrequencyImagesService.run(id);
        if(StringUtils.isEmpty(errorMsg)){
            return success(errorMsg);
        } else {
            return error(errorMsg);
        }
    }

    @PreAuthorize("@ss.hasPermi('biz:images:add')")
    @GetMapping(value = "/getTaskStatusIsChanged/{id}")
    public AjaxResult getTaskStatusIsChanged(@PathVariable("id") Long id){
        return success(timeFrequencyImagesService.getTaskStatusIsChanged(id));
    }
}
