package com.ips.system.service.impl;

import java.util.List;
import java.util.Map;

import com.ips.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ips.system.mapper.AlgorithmConfigMapper;
import com.ips.system.domain.AlgorithmConfig;
import com.ips.system.service.IAlgorithmConfigService;

/**
 * 算法配置Service业务层处理
 * 
 * @author Allen
 * @date 2025-05-21
 */
@Service
public class AlgorithmConfigServiceImpl implements IAlgorithmConfigService 
{
    @Autowired
    private AlgorithmConfigMapper algorithmConfigMapper;

    /**
     * 查询算法配置
     * 
     * @param id 算法配置主键
     * @return 算法配置
     */
    @Override
    public AlgorithmConfig selectAlgorithmConfigById(Long id)
    {
        return algorithmConfigMapper.selectAlgorithmConfigById(id);
    }

    /**
     * 查询算法配置列表
     * 
     * @param algorithmConfig 算法配置
     * @return 算法配置
     */
    @Override
    public List<AlgorithmConfig> selectAlgorithmConfigList(AlgorithmConfig algorithmConfig)
    {
        return algorithmConfigMapper.selectAlgorithmConfigList(algorithmConfig);
    }

    /**
     * 新增算法配置
     * 
     * @param algorithmConfig 算法配置
     * @return 结果
     */
    @Override
    public int insertAlgorithmConfig(AlgorithmConfig algorithmConfig)
    {
        algorithmConfig.setCreateTime(DateUtils.getNowDate());
        return algorithmConfigMapper.insertAlgorithmConfig(algorithmConfig);
    }

    /**
     * 修改算法配置
     * 
     * @param algorithmConfig 算法配置
     * @return 结果
     */
    @Override
    public int updateAlgorithmConfig(AlgorithmConfig algorithmConfig)
    {
        algorithmConfig.setUpdateTime(DateUtils.getNowDate());
        return algorithmConfigMapper.updateAlgorithmConfig(algorithmConfig);
    }

    /**
     * 批量删除算法配置
     * 
     * @param ids 需要删除的算法配置主键
     * @return 结果
     */
    @Override
    public int deleteAlgorithmConfigByIds(Long[] ids)
    {
        return algorithmConfigMapper.deleteAlgorithmConfigByIds(ids);
    }

    /**
     * 删除算法配置信息
     * 
     * @param id 算法配置主键
     * @return 结果
     */
    @Override
    public int deleteAlgorithmConfigById(Long id)
    {
        return algorithmConfigMapper.deleteAlgorithmConfigById(id);
    }

    @Override
    public List<Map> getOptionsByType(String type) {
        return algorithmConfigMapper.getOptionsByType(type);
    }
}
